@@ -1,12 +1,12 @@
 package Form::Tiny::Form;
-$Form::Tiny::Form::VERSION = '2.14';
+$Form::Tiny::Form::VERSION = '2.15';
 use v5.10;
 use strict;
 use warnings;
 use Types::Standard qw(Maybe ArrayRef InstanceOf HashRef Bool);
 use Carp qw(croak);
 use Scalar::Util qw(blessed);
-use List::Util qw(any);
+use List::Util qw(first);
 
 use Form::Tiny::Error;
 use Form::Tiny::Utils qw(try);
@@ -162,6 +162,19 @@ sub _ft_validate_nested
 	}
 }
 
+sub _ft_find_field
+{
+	my ($self, $name, $raise) = @_;
+
+	my $def = first { $_->name eq $name } @{$self->field_defs};
+
+	if ($raise && !defined $def) {
+		croak "form does not contain a field definition for $name";
+	}
+
+	return $def;
+}
+
 sub valid
 {
 	my ($self) = @_;
@@ -242,11 +255,8 @@ sub add_error
 	}
 
 	# check if the field exists
-	for my $name ($error->field) {
-		croak "form does not contain a field definition for $name"
-			if defined $name && !any { $_->name eq $name }
-			@{$self->field_defs};
-	}
+	$self->_ft_find_field($error->field, 1)
+		if $error->has_field;
 
 	# unwrap nested form errors
 	$error = $error->error
@@ -274,6 +284,14 @@ sub has_errors
 	return @{$_[0]->errors} > 0;
 }
 
+sub value
+{
+	my ($self, $field_name) = @_;
+	my $field_def = $self->_ft_find_field($field_name, 1);
+
+	return $field_def->get_name_path->follow($self->fields);
+}
+
 1;
 
 __END__
@@ -344,6 +362,23 @@ I<validate> does the same thing, but instead of returning a boolean it returns a
 
 Both methods take input data as the only argument.
 
+=head3 value
+
+	if ($form->valid) {
+		my $value = $form->value('field_name');
+		my $values_array_ref = $form->value('array.*');
+	}
+
+Can be used to interact with L</fields> hashref indirectly with key safety checks.
+
+After validation, this method returns form value of the given field. If the form was not yet validated or the validation was unsuccessful, returns C<undef>.
+
+Accepts a single argument: a field name. Will raise an exception if such field was not defined.
+
+If the field contains an array (C<*>) will return an array reference of all values for that field. Order of those values will be the same as in the input array(s).
+
+I<Note:> currently, the field name passed must be a full field name (not a part of field name). For example, passing C<hash.hash> when the field is specified as C<hash.hash.field> will raise an exception. This may change in the future.
+
 =head3 errors_hash
 
 Helper method which returns errors much like the C<errors> form attribute, but in a hash reference with form field names as keys. Errors not assigned to any specific field end up in empty string key. The values are array references of error messages (strings).
